@@ -5,28 +5,33 @@ import sys
 import cv2
 import numpy as np
 from .error import FileNotExistError
-from six import PY3
+from six import PY2, PY3
+from airtest.aircv.utils import cv2_2_pil, compress_image
 
 
-def imread(filename):
+def imread(filename, flatten=False):
     """根据图片路径，将图片读取为cv2的图片处理格式."""
     if not os.path.isfile(filename):
         raise FileNotExistError("File not exist: %s" % filename)
+
+    # choose image readin mode: cv2.IMREAD_UNCHANGED=-1, cv2.IMREAD_GRAYSCALE=0, cv2.IMREAD_COLOR=1,
+    readin_mode = cv2.IMREAD_GRAYSCALE if flatten else cv2.IMREAD_COLOR
+
     if PY3:
-        img = cv2.imdecode(np.fromfile(filename, dtype=np.uint8), cv2.IMREAD_UNCHANGED)
+        img = cv2.imdecode(np.fromfile(filename, dtype=np.uint8), readin_mode)
     else:
         filename = filename.encode(sys.getfilesystemencoding())
-        img = cv2.imread(filename, 1)
+        img = cv2.imread(filename, readin_mode)
+
     return img
 
 
-def imwrite(filename, img):
-    """写出图片到本地路径"""
-    if PY3:
-        cv2.imencode('.jpg', img)[1].tofile(filename)
-    else:
+def imwrite(filename, img, quality=10, max_size=None):
+    """写出图片到本地路径，压缩"""
+    if PY2:
         filename = filename.encode(sys.getfilesystemencoding())
-        cv2.imwrite(filename, img)
+    pil_img = cv2_2_pil(img)
+    compress_image(pil_img, filename, quality, max_size=max_size)
 
 
 def show(img, title="show_img", test_flag=False):
@@ -75,7 +80,7 @@ def crop_image(img, rect):
         (airtest中有用到)
     """
 
-    if isinstance(rect, (list, tuple)):
+    if isinstance(rect, (list, tuple)) and len(rect) == 4:
         height, width = img.shape[:2]
         # 获取在图像中的实际有效区域：
         x_min, y_min, x_max, y_max = [int(i) for i in rect]
