@@ -97,6 +97,9 @@ def log(arg, timestamp=None, desc="", snapshot=False):
     if G.LOGGER:
         depth = 0
         if snapshot:
+            # 如果指定了snapshot参数，强制保存一张图片
+            save_image = ST.SAVE_IMAGE
+            ST.SAVE_IMAGE = True
             try:
                 try_log_screen(depth=2)
             except AttributeError:
@@ -104,6 +107,8 @@ def log(arg, timestamp=None, desc="", snapshot=False):
                 pass
             else:
                 depth = 1
+            finally:
+                ST.SAVE_IMAGE = save_image
         if isinstance(arg, Exception):
             if hasattr(arg, "__traceback__"):
                 # in PY3, arg.__traceback__ is traceback object
@@ -114,13 +119,16 @@ def log(arg, timestamp=None, desc="", snapshot=False):
                     "name": desc or arg.__class__.__name__,
                     "traceback": trace_msg,
                 }, depth=depth, timestamp=timestamp)
+            G.LOGGING.error(trace_msg)
         elif isinstance(arg, six.string_types):
             # 普通文本log内容放在"log"里，如果有trace内容放在"traceback"里
             # 在报告中，假如"traceback"有内容，将会被识别为报错，这个步骤会被判定为不通过
             G.LOGGER.log("info", {"name": desc or arg, "traceback": None, "log": arg}, depth=depth, timestamp=timestamp)
+            G.LOGGING.info(arg)
         else:
             G.LOGGER.log("info", {"name": desc or repr(arg), "traceback": None, "log": repr(arg)}, depth=depth,
                          timestamp=timestamp)
+            G.LOGGING.info(repr(arg))
 
 
 def logwrap(f):
